==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_GraphicsPen.cpp <==
//----------------------------------------------------------------------------
// wxGraphicsPen
// extracted from graphicspen.tex
//----------------------------------------------------------------------------
#include "stdafx.h"

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class derivation
//----------------------------------------------------------------------------
class wx_GraphicsPen: public wxGraphicsPen, public GuraObjectObserver {
private:
	Gura::Signal _sig;
	Object_wx_GraphicsPen *_pObj;
public:
	~wx_GraphicsPen();
	inline void AssocWithGura(Gura::Signal &sig, Object_wx_GraphicsPen *pObj) {
		_sig = sig, _pObj = pObj;
	}
	// virtual function of GuraObjectObserver
	virtual void GuraObjectDeleted();
};

wx_GraphicsPen::~wx_GraphicsPen()
{
	if (_pObj != NULL) _pObj->InvalidateEntity();
}

void wx_GraphicsPen::GuraObjectDeleted()
{
	_pObj = NULL;
}

//----------------------------------------------------------------------------
// Gura interfaces for wxGraphicsPen
//----------------------------------------------------------------------------

//----------------------------------------------------------------------------
// Object implementation for wxGraphicsPen
//----------------------------------------------------------------------------
Object_wx_GraphicsPen::~Object_wx_GraphicsPen()
{
}

Object *Object_wx_GraphicsPen::Clone() const
{
	return NULL;
}

String Object_wx_GraphicsPen::ToString(bool exprFlag)
{
	String rtn("<wx.GraphicsPen:");
	if (GetEntity() == NULL) {
		rtn += "invalid>";
	} else {
		char buff[64];
		::sprintf(buff, "%p>", GetEntity());
		rtn += buff;
	}
	return rtn;
}

//----------------------------------------------------------------------------
// Class implementation for wxGraphicsPen
//----------------------------------------------------------------------------
Gura_ImplementUserInheritableClass(wx_GraphicsPen)
{
}

Gura_ImplementDescendantCreator(wx_GraphicsPen)
{
	return new Object_wx_GraphicsPen((pClass == NULL)? this : pClass, NULL, NULL, OwnerFalse);
}

Gura_EndModuleScope(wx)

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_GraphicsPen.cpp <==
//----------------------------------------------------------------------------
// wxGraphicsPen
// extracted from graphicspen.tex
//----------------------------------------------------------------------------
#include "stdafx.h"

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class derivation
//----------------------------------------------------------------------------
class wx_GraphicsPen: public wxGraphicsPen, public GuraObjectObserver {
private:
	//Gura::Signal *_pSig;
	Object_wx_GraphicsPen *_pObj;
public:
	~wx_GraphicsPen();
	inline void AssocWithGura(Object_wx_GraphicsPen *pObj) {
		_pObj = pObj;
	}
	// virtual function of GuraObjectObserver
	virtual void GuraObjectDeleted();
};

wx_GraphicsPen::~wx_GraphicsPen()
{
	if (_pObj != nullptr) _pObj->InvalidateEntity();
}

void wx_GraphicsPen::GuraObjectDeleted()
{
	_pObj = nullptr;
}

//----------------------------------------------------------------------------
// Gura interfaces for wxGraphicsPen
//----------------------------------------------------------------------------

//----------------------------------------------------------------------------
// Object implementation for wxGraphicsPen
//----------------------------------------------------------------------------
Object_wx_GraphicsPen::~Object_wx_GraphicsPen()
{
}

Object *Object_wx_GraphicsPen::Clone() const
{
	return nullptr;
}

String Object_wx_GraphicsPen::ToString(bool exprFlag)
{
	String rtn("<wx.GraphicsPen:");
	if (GetEntity() == nullptr) {
		rtn += "invalid>";
	} else {
		char buff[64];
		::sprintf(buff, "%p>", GetEntity());
		rtn += buff;
	}
	return rtn;
}

//----------------------------------------------------------------------------
// Class implementation for wxGraphicsPen
//----------------------------------------------------------------------------
Gura_ImplementUserInheritableClass(wx_GraphicsPen)
{
}

Gura_ImplementDescendantCreator(wx_GraphicsPen)
{
	return new Object_wx_GraphicsPen((pClass == nullptr)? this : pClass, nullptr, nullptr, OwnerFalse);
}

Gura_EndModuleScope(wx)
